@@ -16,21 +16,20 @@ class AdminjDateWidget(jforms.jDateInput):
             "jquery.ui.datepicker.jalali/scripts/jquery.ui.datepicker-cc.js",
             "jquery.ui.datepicker.jalali/scripts/calendar.js",
             "jquery.ui.datepicker.jalali/scripts/jquery.ui.datepicker-cc-fa.js",
-            "main.js"
+            "main.js",
         ]
 
         css = {
-            'all': [
+            "all": [
                 "admin/jquery.ui.datepicker.jalali/themes/base/jquery-ui.min.css",
-                "admin/css/main.css"
-                ]
+                "admin/css/main.css",
+            ]
         }
 
-        return forms.Media(js=[static("admin/%s" % path) for path in js],
-                           css=css)
+        return forms.Media(js=[static("admin/%s" % path) for path in js], css=css)
 
     def __init__(self, attrs=None, format=None):
-        final_attrs = {'class': 'vjDateField', 'size': '10'}
+        final_attrs = {"class": "vjDateField", "size": "10"}
         if attrs is not None:
             final_attrs.update(attrs)
         super().__init__(attrs=final_attrs, format=format)
@@ -40,6 +39,7 @@ class AdminSplitjDateTime(forms.SplitDateTimeWidget):
     """
     A SplitDateTime Widget that has some admin-specific styling.
     """
+
     def __init__(self, attrs=None):
         widgets = [AdminjDateWidget, AdminTimeWidget]
         # Note that we're calling MultiWidget, not SplitDateTimeWidget, because
@@ -47,7 +47,12 @@ class AdminSplitjDateTime(forms.SplitDateTimeWidget):
         forms.MultiWidget.__init__(self, widgets, attrs)
 
     def format_output(self, rendered_widgets):
-        return mark_safe(u'<p class="datetime">%s %s<br />%s %s</p>' % (
-            _('Date:'), rendered_widgets[0], _('Time:'),
-            rendered_widgets[1],
-        ))
+        return mark_safe(
+            '<p class="datetime">%s %s<br />%s %s</p>'
+            % (
+                _("Date:"),
+                rendered_widgets[0],
+                _("Time:"),
+                rendered_widgets[1],
+            )
+        )
