@@ -12,7 +12,7 @@ from django_jalali.forms.widgets import jDateInput, jDateTimeInput
 class jDateField(forms.Field):
     widget = jDateInput
     default_error_messages = {
-        'invalid': _(u'Enter a valid date.'),
+        "invalid": _("Enter a valid date."),
     }
 
     def __init__(self, input_formats=None, *args, **kwargs):
@@ -32,7 +32,7 @@ class jDateField(forms.Field):
             return value
 
         groups = re.search(
-            r'(?P<year>[\d]{1,4})-(?P<month>[\d]{1,2})-(?P<day>[\d]{1,2})',
+            r"(?P<year>[\d]{1,4})-(?P<month>[\d]{1,2})-(?P<day>[\d]{1,2})",
             value,
         )
         try:
@@ -45,13 +45,13 @@ class jDateField(forms.Field):
         except (ValueError, AttributeError):
             pass
 
-        raise exceptions.ValidationError(self.error_messages['invalid'])
+        raise exceptions.ValidationError(self.error_messages["invalid"])
 
 
 class jDateTimeField(forms.Field):
     widget = jDateTimeInput
     default_error_messages = {
-        'invalid': _(u'Enter a valid date/time.'),
+        "invalid": _("Enter a valid date/time."),
     }
 
     def __init__(self, input_formats=None, *args, **kwargs):
@@ -79,26 +79,29 @@ class jDateTimeField(forms.Field):
             # Input comes from a SplitDateTimeWidget, for example. So, it's two
             # components: date and time.
             if len(value) != 2:
-                raise exceptions.ValidationError(self.error_messages['invalid'])
-            if value[0] in validators.EMPTY_VALUES and value[1] in validators.EMPTY_VALUES:
+                raise exceptions.ValidationError(self.error_messages["invalid"])
+            if (
+                value[0] in validators.EMPTY_VALUES
+                and value[1] in validators.EMPTY_VALUES
+            ):
                 return None
-            value = '%s %s' % tuple(value)
+            value = "%s %s" % tuple(value)
 
         groups = re.search(
-            r'(?P<year>[\d]{1,4})-(?P<month>[\d]{1,2})-(?P<day>[\d]{1,2}) '
-            r'(?P<hour>[\d]{1,2}):(?P<minute>[\d]{1,2})'
-            r'(:(?P<second>[\d]{1,2}))?(.(?P<microsecond>[\d]{1,5}))?',
-            value
+            r"(?P<year>[\d]{1,4})-(?P<month>[\d]{1,2})-(?P<day>[\d]{1,2}) "
+            r"(?P<hour>[\d]{1,2}):(?P<minute>[\d]{1,2})"
+            r"(:(?P<second>[\d]{1,2}))?(.(?P<microsecond>[\d]{1,5}))?",
+            value,
         )
         try:
-            microsecond = int(groups.group('microsecond') or 0)
-            second = int(groups.group('second') or 0)
+            microsecond = int(groups.group("microsecond") or 0)
+            second = int(groups.group("second") or 0)
             result = jdatetime.datetime(
-                year=int(groups.group('year')),
-                month=int(groups.group('month')),
-                day=int(groups.group('day')),
-                hour=int(groups.group('hour')),
-                minute=int(groups.group('minute')),
+                year=int(groups.group("year")),
+                month=int(groups.group("month")),
+                day=int(groups.group("day")),
+                hour=int(groups.group("hour")),
+                minute=int(groups.group("minute")),
                 second=second,
                 microsecond=microsecond,
             )
@@ -107,4 +110,4 @@ class jDateTimeField(forms.Field):
         except (ValueError, AttributeError):
             pass
 
-        raise exceptions.ValidationError(self.error_messages['invalid'])
+        raise exceptions.ValidationError(self.error_messages["invalid"])
